--------------------------------------------------------------------------------
title: Why Nokia chose Windows over Android
date: 2011-02-11 22:24:00
categories:
  - Android
--------------------------------------------------------------------------------

Today, we have all heard about the new deal struck between Nokia and Microsoft.
It is a major change in Nokia's strategy which will without a doubt affect the
smartphone market.

A few month ago, the Executive Vice President of Nokia [announced][peeing]
that switching to Android is like peeing in your boots for warmth. Well, let me
say this: if switching to Android is like peeing in your boots, switching to
Windows is like shitting your pants.

Perhaps, Nokia liked the latter better.

[peeing]: "http://www.mobilecrunch.com/2010/09/22/nokia-evp-anssi-vanjoki-switching-to-android-is-like-peeing-in-your-pants-for-warmth/"
